# pygocomma

Control Gocomma R9 devices with Python 3 using asyncio (single threaded with event loop).
Tu use the library you need the id and key of your device. You can get them using any of [those](https://github.com/clach04/python-tuya/wiki) methods.

## Usage

TBD
```python
print("TBD")
```

## Contributions

Pull requests are welcome. 

## Disclaimer

Not affiliated with Gocomma in any way.


### Related Projects

  * https://github.com/codetheweb/tuyapi node.js
  * https://github.com/sean6541/tuyaapi Python API to the web api
  * https://github.com/clach04/python-tuya/ Python API to the web api